@@ -1,5 +1,5 @@
 /// VirusTotal API v3
-/// Clean & Simple interface to access the VirusTotal v3 REST api's
+/// Clean & Simple interface to access the VirusTotal v3 Public & Enterprise REST api's
 /// ## Usage
 /// ```toml
 /// [dependencies]
@@ -11,31 +11,34 @@
 /// let vt_client = vt3::VtClient::new("YOUR API KEY");
 /// ```
 ///
+mod domain;
 mod file;
 mod ip;
 mod url;
-mod domain;
 
 #[cfg(feature = "enterprise")]
 mod enterprise;
+
 #[cfg(feature = "enterprise")]
-pub use self::enterprise::{
-    retrohunt::SubmitJobRoot,
-    livehunt::SubmitRulesetRoot,
-};
+pub use self::enterprise::{livehunt::SubmitRulesetRoot, retrohunt::SubmitJobRoot};
+
+static DEFAULT_USER_AGENT: &str = "rust-client/vt3-rs+https://github.com/marirs/vt3-rs";
 
-mod utils;
 pub mod error;
+mod utils;
 
-#[derive(Copy, Clone)]
-pub struct VtClient<'a> {
-    api_key: &'a str,
-    endpoint: &'a str,
-    user_agent: &'a str,
+use error::VtError;
+pub type VtResult<T> = Result<T, VtError>;
+
+#[derive(Clone)]
+pub struct VtClient {
+    api_key: String,
+    endpoint: String,
+    user_agent: String,
 }
 
-impl<'a> VtClient<'a> {
-    pub fn new(api_key: &'a str) -> Self {
+impl VtClient {
+    pub fn new(api_key: &str) -> Self {
         //! Creates a new VirusTotal API Client to access the VirusTotal REST API v3
         //!
         //! ## Example usage
@@ -45,15 +48,15 @@ impl<'a> VtClient<'a> {
         //! let vt_client = VtClient::new("YOUR API KEY");
         //! ```
         VtClient {
-            api_key,
-            endpoint: "https://www.virustotal.com/api/v3",
-            user_agent: "rust-client/vt3-rs+https://github.com/marirs/vt3-rs",
+            api_key: api_key.into(),
+            endpoint: "https://www.virustotal.com/api/v3".into(),
+            user_agent: DEFAULT_USER_AGENT.into(),
         }
     }
 
     /// Sets a new user-agent that from the default
-    pub fn user_agent(&'a mut self, user_agent: &'a str) -> &'a mut VtClient {
-        self.user_agent = user_agent;
+    pub fn user_agent(&mut self, user_agent: &str) -> &mut VtClient {
+        self.user_agent = user_agent.into();
         self
     }
 }
